package com.joshvm.demo;

import org.joshvm.j2me.dio.DeviceManager;
import org.joshvm.j2me.dio.gpio.GPIOPin;
import org.joshvm.j2me.dio.gpio.GPIOPinConfig;
import org.joshvm.j2me.dio.gpio.PinEvent;
import org.joshvm.j2me.dio.gpio.PinListener;


/**
 * 提供GPIO相关功能Demo
 * <p>
 * 以2G开发板为例：GPIO_1=4,GPIO_2=27,GPIO_3=29,PWM/IO=25
 * <p>
 * 请按照相关设备的硬件文档，进行相关参数配置
 * 
 * @author JOSH
 *
 */
public class GPIOReceiveDemo {
	private static final int GPIO_Pin_1 = 4;
	private static final int GPIO_Pin_2 = 27;
	private static final int GPIO_Pin_3 = 29;
	
	public static void main(String[] args) {
		
		System.out.println("      ===============      Start GPIOReceive Demo...");
		
		try {

			/* 按键等输入设备 */
			// 设定为输入设备，支持上拉输入模式
			// 2G开发板的触发模式为： TRIGGER_LOW_LEVEL、TRIGGER_HIGH_LEVEL
			// 4G开发板的触发模式为：TRIGGER_BOTH_LEVELS
			// 2G、4G电平高低都会响应监听
			// InitValue不处理，可以随意填写
			
			
			GPIOPinConfig cfgInput1 = new GPIOPinConfig(GPIOPinConfig.UNASSIGNED, GPIO_Pin_1, GPIOPinConfig.DIR_INPUT_ONLY,
					GPIOPinConfig.MODE_INPUT_PULL_UP, GPIOPinConfig.TRIGGER_LOW_LEVEL, true);
			GPIOPin inputGpio1 = (GPIOPin) DeviceManager.open(cfgInput1, DeviceManager.EXCLUSIVE);
			
			GPIOPinConfig cfgInput2 = new GPIOPinConfig(GPIOPinConfig.UNASSIGNED, GPIO_Pin_2, GPIOPinConfig.DIR_INPUT_ONLY,
					GPIOPinConfig.MODE_INPUT_PULL_UP, GPIOPinConfig.TRIGGER_LOW_LEVEL, true);
			GPIOPin inputGpio2 = (GPIOPin) DeviceManager.open(cfgInput2, DeviceManager.EXCLUSIVE);
			
			GPIOPinConfig cfgInput3 = new GPIOPinConfig(GPIOPinConfig.UNASSIGNED, GPIO_Pin_3, GPIOPinConfig.DIR_INPUT_ONLY,
					GPIOPinConfig.MODE_INPUT_PULL_UP, GPIOPinConfig.TRIGGER_LOW_LEVEL, true);
			GPIOPin inputGpio3 = (GPIOPin) DeviceManager.open(cfgInput3, DeviceManager.EXCLUSIVE);
			
			// 设置监听
			inputGpio1.setInputListener(new PinListener() {
				public void valueChanged(PinEvent event) {

					System.out.println(event.getValue());

					if (event.getValue()) {
						// 拉高
						System.out.println("      ===============       GPIO 1 is HIGH");
					} else {
						// 拉低
						System.out.println("      ===============       GPIO 1 is LOW");
					}
				}
			});
			
			// 设置监听
			inputGpio2.setInputListener(new PinListener() {
				public void valueChanged(PinEvent event) {

					System.out.println(event.getValue());

					if (event.getValue()) {
						// 拉高
						System.out.println("      ===============       GPIO 2 is HIGH");
					} else {
						// 拉低
						System.out.println("      ===============       GPIO 2 is LOW");
					}
				}
			});
			
			// 设置监听
			inputGpio3.setInputListener(new PinListener() {
				public void valueChanged(PinEvent event) {

					System.out.println(event.getValue());

					if (event.getValue()) {
						// 拉高
						System.out.println("      ===============       GPIO 3 is HIGH");
					} else {
						// 拉低
						System.out.println("      ===============       GPIO 3 is LOW");
					}
				}
			});

		} catch (Exception e) {
			e.printStackTrace();
		}
		
	}
		
	

}
